@@ -24,12 +24,13 @@ def chunk_dict(d, n):
 @task()
 def doReset():
     lemmas = loadLemmas()
-    lemma_job = group(addLemmas.si(x) for x in chunk_dict(lemmas,10000))
+    #lemma_job = group(addLemmas.si(x) for x in chunk_dict(lemmas,10000))
     wfs,spells,trans = loadWF()
-    wf_job = group(addWFS.si(x) for x in chunk_dict(wfs,10000))
-    spell_job = group(addSpells.si(x) for x in chunks(spells,10000))
-    trans_job = group(addTrans.si(x) for x in chunks(trans,10000))
-    c2 = (loadCats.si() | lemma_job | wf_job |spell_job | trans_job | addRelationships.si(wfs))
+    #wf_job = group(addWFS.si(x) for x in chunk_dict(wfs,10000))
+    #spell_job = group(addSpells.si(x) for x in chunks(spells,10000))
+    #trans_job = group(addTrans.si(x) for x in chunks(trans,10000))
+    ajob = group([addLemmas.si(lemmas),addSpells.si(spells),addTrans.si(trans)]
+    c2 = (loadCats.si() | ajob | addWFS.si(wfs) | addRelationships.si(wfs))
     res = c2()
     res.get()
 
